Revision 4be5fae by Kévin Dietrich / Sergey Sharybin (blender-v2.78-release, blender-v2.78b-release, blender-v2.78c-release, fracture_modifier, fracture_modifier-master, temp-fracture-modifier-2.8) September 14, 2016, 08:26 (GMT) |
Fix T49249: Alembic export with multiple hair systems crash blender Crash was due to a name collision in Alembic objects caused by the fact that names derive from the one of the Blender object. An object having multiple particles system would thus give its name to various subobjects. Now use the name of the particles system for the Alembic object. |
Revision 184c781 by Brecht Van Lommel / Sergey Sharybin (blender-v2.78-release, blender-v2.78b-release, blender-v2.78c-release, fracture_modifier, fracture_modifier-master, temp-fracture-modifier-2.8) September 14, 2016, 08:26 (GMT) |
Fix a few OpenCL compiler warnings. |
Revision 91705ad by Gaia Clary / Sergey Sharybin (blender-v2.78-release, blender-v2.78b-release, blender-v2.78c-release, fracture_modifier, fracture_modifier-master, temp-fracture-modifier-2.8) September 14, 2016, 08:26 (GMT) |
fix: not initialised variable can crash blender (related to modifiers with cage editing enabled) |
Revision ab934e7 by Bastien Montagne / Sergey Sharybin (blender-v2.78-release, blender-v2.78b-release, blender-v2.78c-release, fracture_modifier, fracture_modifier-master, temp-fracture-modifier-2.8) September 14, 2016, 08:26 (GMT) |
Fix T49228: Separate by material, materials dissappear after reload. Yet another mismatch where code would decrease usercount (of Material here) but never increase it again when re-assigning the datablock... |
Revision 894a4f5 by Bastien Montagne / Sergey Sharybin (blender-v2.78-release, blender-v2.78b-release, blender-v2.78c-release, fracture_modifier, fracture_modifier-master, temp-fracture-modifier-2.8) September 14, 2016, 08:26 (GMT) |
Fix T49229: ID user decrement error when deleting group instance twice. Another great example of inconsistency in usercount handling - dupli_group was considered as refcounted by readfile.c code (and hence by library_query.c one, which is based on it), but not by editor/BKE_object code, which never increased group's usercount when creating an instance of it etc. To be backported to 2.78. |
September 13, 2016, 23:47 (GMT) |
Merge branch 'soc-2016-pbvh-painting' of git.blender.org:blender into soc-2016-pbvh-painting |
September 13, 2016, 23:47 (GMT) |
Refactoring |
September 13, 2016, 17:02 (GMT) |
FileBrowser: Always do full cache refresh while we are still listing... Does not seem to be a problem with embeded filelisting code, but was breaking with some experimental asset engines. |
September 13, 2016, 16:50 (GMT) |
Claude: Fix erroneous uuid generation. This uuid generation is just temp placeholder anyway, we want something based on actual uuid of Cloud items, but at least let's avoid generating several time the same ID in current listing! |
September 13, 2016, 16:00 (GMT) |
Merge branch 'master' into asset-engine |
September 13, 2016, 13:30 (GMT) |
Cleanup: Line length, indentation, etc |
September 13, 2016, 12:13 (GMT) |
Cleanup: Reduce diff from master (mostly emty lines...). |
September 13, 2016, 12:05 (GMT) |
Merge branch 'master' into soc-2016-pbvh-painting |
September 13, 2016, 11:46 (GMT) |
Cycles: Implement threaded SVM nodes compilation The title says it all actually. From tests with barber shop scene here gives 2-3x speedup for shader compilation on my oldie i7 machine. The gain is mainly due to textures metadata query from jpeg files (which seems to requite de-compression before metadata can be read). But in theory could give nice improvements for scenes with huge node trees as well (i'm talking about node trees of complexity of fractal which we had reports about in the past). Reviewers: juicyfruit, dingto, lukasstockner97, brecht Reviewed By: brecht Subscribers: monio, Blendify Differential Revision: https://developer.blender.org/D2215 |
September 13, 2016, 11:23 (GMT) |
Fix bpy.data.user_map() ignoring unused datablocks. Should be backported to 2.78. Found by Sybren here in studio, thanks! |
September 13, 2016, 11:12 (GMT) |
Outliner: Report linked datablock edit failure when trying to rename linked data in outliner |
September 13, 2016, 10:38 (GMT) |
Fix T49323: Ineffective bone roll calculation with low rig scale The code was expecting vector to be normalized, however after applying inverted object matrix it was possible to have scale applied to it. |
September 13, 2016, 09:33 (GMT) |
Fix T49336: Outliner allows to edit restrict flags for linked objects |
September 13, 2016, 09:05 (GMT) |
Cycles: Tweak empty boundbox children The idea here is to make assert failure to fail sooner on an incorrect node address rather than later with stack overflow. |
September 13, 2016, 08:59 (GMT) |
Fix T49290: Specific .blend with hair crashes in MacOS 2.78 RC1 on render The issue was caused by some false-positive empty non-AABB intersection. Tried to tweak it a bit so it does not record intersection anymore. Hopefully will work for all platforms. Tested here on iMac and Debian. |
|
|
|


Master Commits
MiikaH:n Sivut a.k.a. MiikaHweb | 2003-2021